# frozen_string_literal: true

module LearnLab
  # Command-line interface.
  #
  class CLI < Thor
    desc 'test', 'Run tests and get a token'
    long_desc <<-LONG_DESC
      `learn-lab test` will run your tests and output a token that can be
      copy/pasted into Canvas.
    LONG_DESC
    # rubocop:disable Metrics/AbcSize
    # rubocop:disable Metrics/MethodLength
    def test
      configuration = Configuration.open
      unless configuration.valid?
        puts 'Please run `learn-lab config` first'
        exit 0
      end
      repo = VCS.new(LearnLab.file_system.pwd)
      results = LearnLab::Test::Runner.new(repo).run
      exit 0 unless results[:failure_count].zero?
      token = Token.new(configuration.email, repo.remote_url)
      puts "Your token is:\n\n"
      puts chunk(token.encoded, 30)
    end
    # rubocop:enable Metrics/AbcSize
    # rubocop:enable Metrics/MethodLength

    desc 'config', 'Configure gem'
    long_desc <<-LONG_DESC
      `learn-lab config` will configure this gem. It will prompt you for any
      information it needs and save the configuration to a file in your $HOME directory.
    LONG_DESC
    def config
      configuration = Configuration.open
      email = configuration.email || '<not set>'

      question = "Enter the email you use to log into Canvas\n" \
        "(your current email is '#{email}'):"

      prompt = Prompt.new

      # TODO: What kind of email validation do we want here?
      configuration.email = prompt.ask(question) { |value| !value.empty? }

      configuration.save!
      puts 'Configuration saved!'
    end

    private

    def chunk(string, size)
      string.scan(/.{1,#{size}}/)
    end
  end
end
