# frozen_string_literal: true

module LearnLab
  # Interface for dealing with persisted configuration file in YAML format.
  #
  class Configuration
    attr_reader :path, :fs
    attr_accessor :email

    def self.open(filename='enterprise.yml', **options)
      fs = options.fetch(:fs) { LearnLab.file_system }
      path = fs.join(fs.home, '.flatiron-school', filename)
      data = fs.read_yaml_file(path)
      new(path, data)
    rescue ConfigurationError
      path = fs.join(fs.home, '.flatiron-school', 'enterprise.yml')
      new(path, {})
    end

    def initialize(path, data, **options)
      @path = path
      @fs = options.fetch(:fs) { LearnLab.file_system }
      @email = data[:email]
    end

    def save!
      directory = fs.dirname(path)
      fs.mkdir(directory) unless fs.directory?(directory)
      fs.write_yaml_file(path, payload, mode: 'w')
    end

    def valid?
      !email.nil?
    end

    private

    def payload
      { 'email' => email }
    end
  end
end
