# frozen_string_literal: true

module LearnLab
  # Wraps file system related commands.
  #
  class FileSystem
    def read_file(path)
      File.read(path)
    end

    def read_yaml_file(path, fallback: {})
      data = YAML.load_file(path, fallback: fallback)
      data.transform_keys(&:to_sym)
    rescue Errno::ENOENT, Psych::SyntaxError => e
      raise ConfigurationError.new(e)
    end

    def read_json_file(path)
      data = File.exist?(path) ? read_file(path) : '{}'
      JSON.parse(data, symbolize_names: true)
    end

    def home
      Dir.home
    end

    def pwd
      FileUtils.pwd
    end

    def join(*args)
      File.join(*args)
    end

    def dirname(path)
      File.dirname(path)
    end

    def mkdir(path)
      FileUtils.mkdir_p(path)
    end

    def directory?(path)
      File.directory?(path)
    end

    def write_yaml_file(path, data, **options)
      File.write(path, data.to_yaml, **options)
    end

    def file_exist?(path)
      File.exist?(path)
    end

    def dir_exist?(path)
      Dir.exist?(path)
    end

    def dir_entries(path)
      Dir.entries(path)
    end

    def rm(path)
      FileUtils.rm(path)
    end
  end
end
