# frozen_string_literal: true

module LearnLab
  module Test
    # Runs a test suite. Lifted from the `learn-test` gem without Ironboard
    # related code.
    #
    class Runner
      attr_reader :repo, :options

      def initialize(repo, options={})
        @repo = repo
        @options = options
      end

      def run
        strategy.check_dependencies
        strategy.run
        results = strategy.results
        strategy.cleanup unless options.fetch(:keep, false)
        results
      end

      def working_directory
        repo.working_directory
      end

      def strategy
        @strategy ||= begin
          detected = strategies.map { |s| s.new(self) }.detect(&:detect)
          detected || LearnLab::Test::Strategies::None.new(self)
        end
      end

      private

      def strategies
        [
          LearnLab::Test::Strategies::Mocha,
          LearnLab::Test::Strategies::Rspec
        ]
      end
    end
  end
end
