# frozen_string_literal: true

module LearnLab
  module Test
    module Strategies
      # Test strategy for Mocha.
      #
      class Mocha < Strategy
        def check_dependencies
          msg = 'Please install NodeJS: https://nodejs.org/en/download'
          raise MissingDependencyError.new(msg) if `which node`.empty?
        end

        def detect
          js_dependency?(:mocha) || js_dependency?(:'learn-browser')
        end

        def run
          command = if js_dependency?(:'learn-browser') || js_test_script?
                      'npm test'
                    else
                      'node_modules/.bin/mocha -R mocha-multi ' \
                        "--reporter-options spec=-,json=#{result_filename}"
                    end
          system(command)
        end

        def parser
          @parser ||= LearnLab::Test::Parsers::Mocha.new(output)
        end

        private

        def js_package
          @js_package ||= begin
            path = fs.join(runner.working_directory, 'package.json')
            fs.read_json_file(path)
          end
        end

        def js_dependency?(dep)
          %i[dependencies devDependencies].any? do |key|
            js_package[key] && js_package[key][dep]
          end
        end

        def js_test_script?
          (js_package[:scripts] && js_package[:scripts][:test] || '') \
            .include?(result_filename)
        end
      end
    end
  end
end
