# frozen_string_literal: true

module LearnLab
  module Test
    module Strategies
      # Test Strategy for RSpec. Mostly lifted from the `learn-test` gem
      # without Ironboard specific code. Some other refactorings were also
      # made to improve test coverage and fix Rubocop warnings.
      #
      class Rspec < Strategy
        def detect
          spec_dir = fs.join(runner.working_directory, 'spec')
          fs.dir_exist?(spec_dir) && \
            (fs.dir_entries(spec_dir).include?('spec_helper.rb') || \
             fs.dir_entries(spec_dir).include?('rails_helper.rb'))
        end

        def run
          command_options = [
            '--format documentation',
            '--format j',
            "--out #{result_filename}"
          ]
          system("#{bundle_command}rspec #{command_options.join(' ')}")
        end

        def parser
          @parser ||= LearnLab::Test::Parsers::Rspec.new(output)
        end

        private

        def bundle_command
          bundler? ? 'bundle exec ' : ''
        end

        def bundler?
          fs.file_exist?('Gemfile') && \
            !!fs.read_file('Gemfile').match(/^\s*gem\s*('|")rspec(-[^'"]+)?('|").*$/)
        end
      end
    end
  end
end
