# frozen_string_literal: true

module LearnLab
  module Test
    # Base class for all test tools. Extracted from the `learn-test` gem with
    # some modifications (i.e. this doesn't talk to Ironboard).
    #
    class Strategy
      attr_reader :runner, :options, :out, :fs

      def initialize(runner, out=$stdout)
        @runner = runner
        @options = runner.options
        @out = out
        @fs = LearnLab.file_system
      end

      def check_dependencies; end

      def run
        raise NotImplementedError.new(
          'you must implement how this strategy runs its tests'
        )
      end

      def parser
        raise NotImplementedError.new('you must define a parser')
      end

      # rubocop:disable Metrics/MethodLength
      def results
        {
          repo_name: runner.repo,
          build: {
            test_suite: [{
              framework: parser.framework,
              formatted_output: output,
              duration: parser.duration
            }]
          },
          example_count: parser.example_count,
          passing_count: parser.passing_count,
          pending_count: parser.pending_count,
          failure_count: parser.failure_count
        }
      end
      # rubocop:enable Metrics/MethodLength

      def output
        return unless result_file?

        fs.read_json_file(result_file_path)
      end

      def cleanup
        fs.rm(result_file_path) if result_file?
      end

      def result_filename
        '.results.json'
      end

      private

      def result_file?
        fs.file_exist?(result_file_path)
      end

      def result_file_path
        fs.join(runner.working_directory, result_filename)
      end
    end
  end
end
