# frozen_string_literal: true

module LearnLab
  # Encodable token. Consists of an email, GitHub URL, and timestamp encoded
  # as a Base64 URL safe string.
  #
  class Token
    attr_reader :email, :url, :timestamp

    def initialize(email, url, timestamp=Time.now.utc)
      @email = email
      @url = url
      @timestamp = timestamp
    end

    def encoded
      Base64.urlsafe_encode64(payload.to_json)
    end

    private

    def payload
      {
        lms_email: email,
        vcs_url: url,
        timestamp: timestamp
      }
    end
  end
end
